@@ -1,5 +1,6 @@
 import string
 import os.path
+import re
 from util import split_list
 
 def is_number (value):
@@ -121,12 +122,12 @@ def is_ipv4 (value):
 
 def is_ipv6 (value):
     from socket import inet_pton, AF_INET6
-    try: 
+    try:
         tmp = inet_pton(AF_INET6, value)
     except:
         raise ValueError, _('Malformed IPv6')
     return value
-    
+
 def is_local_dir_exists (value, cfg, nochroot=False):
     value = is_path (value)
 
@@ -263,7 +264,11 @@ def debug_fail (value):
     raise ValueError, _('Forced failure')
 
 def is_regex (value):
-    # Can a regular expression be checked?
+    try:
+        trash = re.compile(value)
+    except:
+        raise ValueError, _('Invalid regular expression')
+
     return value
 
 def is_http_url (value):
@@ -318,4 +323,4 @@ def is_new_host (value, cfg, nochroot):
             raise ValueError, _('Virtual host nick is already being used.')
     return value
 
-            
+
