@@ -335,6 +335,7 @@ purge_connection (cherokee_thread_t *thread, cherokee_connection_t *conn)
 
 	/* It maybe have a delayed log
 	 */
+	cherokee_connection_update_vhost_traffic (conn);
 	cherokee_connection_log (conn);
 
 	/* Close & clean the socket and clean up the connection object
@@ -442,14 +443,10 @@ close_active_connection (cherokee_thread_t *thread, cherokee_connection_t *conn)
 static void
 maybe_purge_closed_connection (cherokee_thread_t *thread, cherokee_connection_t *conn)
 {
-	/* Log if it was delayed and update vserver traffic counters
-	 */
-	cherokee_connection_update_vhost_traffic (conn);
-	cherokee_connection_log (conn);
-
-	/* If it isn't a keep-alive connection, it should try to
-	 * perform a lingering close (there is no need to disable TCP
-	 * cork before shutdown or before a close).
+	/* CONNECTION CLOSE: If it isn't a keep-alive connection, it
+	 * should try to perform a lingering close (there is no need
+	 * to disable TCP cork before shutdown or before a close).
+	 * Logging is performed after the lingering close.
 	 */
 	if (conn->keepalive <= 0) {
 		conn->phase = phase_shutdown;
@@ -458,6 +455,11 @@ maybe_purge_closed_connection (cherokee_thread_t *thread, cherokee_connection_t
 
 	conn->keepalive--;
 
+	/* Log
+	 */
+	cherokee_connection_update_vhost_traffic (conn);
+	cherokee_connection_log (conn);
+
 	/* There might be data in the kernel buffer. Flush it before
 	 * the connection is reused for the next keep-alive request.
 	 * If not flushed, the data would remain on the buffer until
@@ -671,7 +673,8 @@ process_active_connections (cherokee_thread_t *thd)
 		}
 		else if ((conn->phase != phase_shutdown) &&
 			 (conn->phase != phase_lingering) &&
-			 (conn->phase != phase_reading_header || conn->incoming_header.len <= 0))
+			 (conn->phase != phase_reading_header || conn->incoming_header.len <= 0) &&
+			 (conn->phase != phase_reading_post || conn->post.send.buffer.len <= 0))
 		{
 			re = cherokee_fdpoll_check (thd->fdpoll,
 						    SOCKET_FD(&conn->socket),
@@ -1078,7 +1081,6 @@ process_active_connections (cherokee_thread_t *thd)
 			conn->phase = phase_reading_post;
 
 		case phase_reading_post:
-
 			/* Read/Send the POST info
 			 */
 			ret = cherokee_connection_read_post (conn);
