@@ -5,7 +5,7 @@
  * Authors:
  *      Alvaro Lopez Ortega <alvaro@alobbs.com>
  *
- * Copyright (C) 2001-2009 Alvaro Lopez Ortega
+ * Copyright (C) 2001-2010 Alvaro Lopez Ortega
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU General Public
@@ -117,9 +117,6 @@ ret_t cherokee_thread_new                        (cherokee_thread_t     **thd,
 
 ret_t cherokee_thread_free                       (cherokee_thread_t  *thd);
 
-ret_t cherokee_thread_accept_on                  (cherokee_thread_t  *thd);
-ret_t cherokee_thread_accept_off                 (cherokee_thread_t  *thd);
-
 ret_t cherokee_thread_unlock                     (cherokee_thread_t *thd);
 ret_t cherokee_thread_wait_end                   (cherokee_thread_t *thd);
 
